Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dial ¶
Dial creates a new QUIC connection it returns once the connection is established and secured with forward-secure keys
func DialContext ¶
DialAddrContext establishes a new QUIC connection to a server using the provided context. See DialAddr for details.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.